@@ -2,7 +2,7 @@ package Test2::Event;
 use strict;
 use warnings;
 
-our $VERSION = '1.302075';
+our $VERSION = '1.302078';
 
 use Test2::Util::HashBase qw/trace nested in_subtest subtest_id/;
 use Test2::Util::ExternalMeta qw/meta get_meta set_meta delete_meta/;
@@ -60,7 +60,7 @@ sub from_json {
 
 sub TO_JSON {
     my $self = shift;
-    return {%$self, __PACKAGE__ => ref $self};
+    return {%$self, Test2::Util::ExternalMeta::META_KEY() => undef, __PACKAGE__ => ref $self};
 }
 
 1;
