@@ -2,11 +2,11 @@ package Test2::Hub;
 use strict;
 use warnings;
 
-our $VERSION = '1.302040';
+our $VERSION = '1.302078';
 
 
 use Carp qw/carp croak confess/;
-use Test2::Util qw/get_tid/;
+use Test2::Util qw/get_tid ipc_separator/;
 
 use Scalar::Util qw/weaken/;
 
@@ -23,6 +23,7 @@ use Test2::Util::HashBase qw{
     _context_init
     _context_release
 
+    active
     count
     failed
     ended
@@ -38,7 +39,7 @@ sub init {
 
     $self->{+PID} = $$;
     $self->{+TID} = get_tid();
-    $self->{+HID} = join '-', $self->{+PID}, $self->{+TID}, $ID_POSTFIX++;
+    $self->{+HID} = join ipc_separator, $self->{+PID}, $self->{+TID}, $ID_POSTFIX++;
 
     $self->{+COUNT}    = 0;
     $self->{+FAILED}   = 0;
@@ -53,6 +54,23 @@ sub init {
     }
 }
 
+sub is_subtest { 0 }
+
+sub _tb_reset {
+    my $self = shift;
+
+    # Nothing to do
+    return if $self->{+PID} == $$ && $self->{+TID} == get_tid();
+
+    $self->{+PID} = $$;
+    $self->{+TID} = get_tid();
+    $self->{+HID} = join ipc_separator, $self->{+PID}, $self->{+TID}, $ID_POSTFIX++;
+
+    if (my $ipc = $self->{+IPC}) {
+        $ipc->add_hub($self->{+HID});
+    }
+}
+
 sub reset_state {
     my $self = shift;
 
@@ -282,9 +300,11 @@ sub process {
     my $is_ok = $type eq 'Test2::Event::Ok';
     my $no_fail = $type eq 'Test2::Event::Diag' || $type eq 'Test2::Event::Note';
     my $causes_fail = $is_ok ? !$e->{effective_pass} : $no_fail ? 0 : $e->causes_fail;
+    my $counted = $is_ok || (!$no_fail && $e->increments_count);
 
-    $self->{+COUNT}++  if $is_ok || (!$no_fail && $e->increments_count);
-    $self->{+FAILED}++ and $self->{+_PASSING} = 0 if $causes_fail;
+    $self->{+COUNT}++      if $counted;
+    $self->{+FAILED}++     if $causes_fail && $counted;
+    $self->{+_PASSING} = 0 if $causes_fail;
 
     my $callback = $e->callback($self) unless $is_ok || $no_fail;
 
@@ -299,7 +319,10 @@ sub process {
     return $e if $is_ok || $no_fail;
 
     my $code = $e->terminate;
-    $self->terminate($code, $e) if defined $code;
+    if (defined $code) {
+        $self->{+_FORMATTER}->terminate($e) if $self->{+_FORMATTER};
+        $self->terminate($code, $e);
+    }
 
     return $e;
 }
@@ -329,9 +352,13 @@ sub finalize {
     my $plan   = $self->{+_PLAN};
     my $count  = $self->{+COUNT};
     my $failed = $self->{+FAILED};
+    my $active = $self->{+ACTIVE};
 
-    # return if NOTHING was done.
-    return unless $do_plan || defined($plan) || $count || $failed;
+	# return if NOTHING was done.
+	unless ($active || $do_plan || defined($plan) || $count || $failed) {
+		$self->{+_FORMATTER}->finalize($plan, $count, $failed, 0, $self->is_subtest) if $self->{+_FORMATTER};
+		return;
+	}
 
     unless ($self->{+ENDED}) {
         if ($self->{+_FOLLOW_UPS}) {
@@ -367,7 +394,11 @@ Second End: $sfile line $sline
     }
 
     $self->{+ENDED} = $frame;
-    $self->is_passing(); # Generate the final boolean.
+    my $pass = $self->is_passing(); # Generate the final boolean.
+
+	$self->{+_FORMATTER}->finalize($plan, $count, $failed, $pass, $self->is_subtest) if $self->{+_FORMATTER};
+
+    return $pass;
 }
 
 sub is_passing {
@@ -376,7 +407,7 @@ sub is_passing {
     ($self->{+_PASSING}) = @_ if @_;
 
     # If we already failed just return 0.
-    my $pass = $self->{+_PASSING} || return 0;
+    my $pass = $self->{+_PASSING} or return 0;
     return $self->{+_PASSING} = 0 if $self->{+FAILED};
 
     my $count = $self->{+COUNT};
@@ -436,7 +467,6 @@ sub DESTROY {
     my $ipc = $self->{+IPC} || return;
     return unless $$ == $self->{+PID};
     return unless get_tid() == $self->{+TID};
-
     $ipc->drop_hub($self->{+HID});
 }
 
@@ -719,6 +749,15 @@ This can be used to disable auto-ending behavior for a hub. The auto-ending
 behavior is triggered by an end block and is used to cull IPC events, and
 output the final plan if the plan was 'no_plan'.
 
+=item $bool = $hub->active
+
+=item $hub->set_active($bool)
+
+These are used to get/set the 'active' attribute. When true this attribute will
+force C<< hub->finalize() >> to take action even if there is no plan, and no
+tests have been run. This flag is useful for plugins that add follow-up
+behaviors that need to run even if no events are seen.
+
 =back
 
 =head2 STATE METHODS
